#!/bin/bash

##
# db-clean-clone.sh performs a clean data migration from a Spokes database created
# from v1.3.2 and earlier version of Spokes.  These database have table migration
# issues with Spokes v1.4.1 or later releases.
#
# The issue is that we had migrated from manual database functions to an ORM
# library called GORM in v1.3.3.  Changes to the GORM library that we updated 
# to in Spokes v1.4.1 has issues with database created without the ORM initially.
#
# What this script does is export the database from the current database
# into INSERT SQL files.  It then creates an empty database and import the data.
# You now have a database created by the underlying ORM with the data.
# 
# It is only necessary to run this script one.  You *MUST* shutdown Spokes
# prior to running it to prevent any data-loss or inconsistency in the new database 
# created.
#
# Contact support@terrapinlabs.co for any questions in inquires on usinf this
# script.
##

##
# Binaries
##
SQLITE="/usr/bin/sqlite3"
SPOKES="/usr/bin/spokes"
CLEAN_CLONE_SQL="/usr/share/spokes/db-clean-clone.sql"

##
# Working directories and variables
##
WORKING_DIR="/tmp/spokes-db-migration"
mkdir -p $WORKING_DIR

##
# Using the spokes program, we create an empty database to import the original
# data using the INSERT SQL.  This new database is stored in the working
# directory.  We need to create an intermediate spokes configuration file to 
# create the empty database.
##
echo '
{
	"dataPath": "'$WORKING_DIR'"
}
' > $WORKING_DIR/config.json

$SPOKES --config $WORKING_DIR/config.json users ls

$SQLITE $WORKING_DIR/spokes.db < $CLEAN_CLONE_SQL

echo "Done: migrated database avaialble at: $WORKING_DIR/spokes.db"
